/*****************************************************************************/
/*									     */
/*    LONGNAME.H -- Declarations for 16-bit long filename API		     */
/*									     */
/*****************************************************************************/

#ifndef _WINDOWS_		 // don't define if we've include NT windows.h

#ifndef LONGNAME_H
#define LONGNAME_H

#ifdef __cplusplus
extern "C" {
#endif

/*****************************************************************************/

/* Type definitions from <windows.h>: */

#ifndef _INC_WINDOWS

#define VOID		    void

#define FAR		    _far
#define NEAR		    _near
#define PASCAL		    _pascal
#define CDECL		    _cdecl

#define WINAPI		    _far _pascal
#define CALLBACK	    _far _pascal

typedef int		    BOOL;
#define FALSE		    0
#define TRUE		    1

typedef char		    CHAR;
typedef unsigned char	    BYTE;
typedef unsigned short	    WORD;
typedef unsigned long	    DWORD;

typedef unsigned int	    UINT;

typedef DWORD FAR *LPDWORD;
typedef VOID FAR *LPVOID;
typedef char FAR *LPTSTR;

typedef WORD HANDLE;

#endif // _INC_WINDOWS

/*****************************************************************************/

/* File attribute bits from <winnt.h>: */

#define FILE_ATTRIBUTE_READONLY 	0x00000001
#define FILE_ATTRIBUTE_HIDDEN		0x00000002
#define FILE_ATTRIBUTE_SYSTEM		0x00000004
#define FILE_ATTRIBUTE_DIRECTORY	0x00000010
#define FILE_ATTRIBUTE_ARCHIVE		0x00000020
#define FILE_ATTRIBUTE_NORMAL		0x00000080

/* FindFirst/FindNext structure from <winbase.h>: */

typedef struct _FILETIME {
    DWORD dwLowDateTime;
    DWORD dwHighDateTime;
} FILETIME, *PFILETIME, FAR *LPFILETIME;

typedef struct _WIN32_FIND_DATA {
    DWORD dwFileAttributes;
    FILETIME ftCreationTime;
    FILETIME ftLastAccessTime;
    FILETIME ftLastWriteTime;
    DWORD nFileSizeHigh;
    DWORD nFileSizeLow;
    DWORD dwReserved0;
    DWORD dwReserved1;
    CHAR   cFileName[260];
    CHAR   cAlternateFileName[14];
} WIN32_FIND_DATA, *PWIN32_FIND_DATA, FAR *LPWIN32_FIND_DATA;

typedef struct _SYSTEMTIME {
    WORD wYear;
    WORD wMonth;
    WORD wDayOfWeek;
    WORD wDay;
    WORD wHour;
    WORD wMinute;
    WORD wSecond;
    WORD wMilliseconds;
} SYSTEMTIME, *PSYSTEMTIME, FAR *LPSYSTEMTIME;

/* Flags returned by GetVolumeInformationEx: */

#define FS_CASE_SENSITIVE	 0x0001
#define FS_CASE_IS_PRESERVED	 0x0002
#define FS_UNICODE_ON_DISK	 0x0004
#define FS_LFN_APIS		 0x4000
#define FS_VOLUME_COMPRESSED	 0x8000

/* Possible error return from handle functions: */

#define INVALID_HANDLE_VALUE ((HANDLE) 0xFFFF)

/*****************************************************************************/

BOOL WINAPI DosDateTimeToFileTime(WORD wFatDate, WORD wFatTime, LPFILETIME
   lpFileTime);

BOOL WINAPI FileTimeToSystemTime(LPFILETIME lpft, LPSYSTEMTIME lpst);

BOOL WINAPI FindClose(HANDLE hFindFile);

HANDLE WINAPI FindFirstFile(LPTSTR lpszPath, LPWIN32_FIND_DATA lpFindData);

BOOL WINAPI FindNextFile(HANDLE hFindFile, LPWIN32_FIND_DATA lpFindData);

DWORD WINAPI GetCurrentDirectory(DWORD cbPath, LPTSTR lpszPath);

DWORD WINAPI GetLastError(void);

BOOL WINAPI GetVolumeInformationEx(LPTSTR lpRoot, LPTSTR lpVolName,
   DWORD cbVolName, LPDWORD lpVolSer, LPDWORD lpMaxName, LPDWORD lpMaxPath,
   LPDWORD lpFlags, LPTSTR lpFSName, DWORD cbFSName);

/*****************************************************************************/

#ifdef __cplusplus
}
#endif

#endif // LONGNAME_H
#endif // _WINDOWS_
